==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/mixin/accessor/ItemSettingsAccessor.java <==
package cc.thonly.reverie_dreams.mixin.accessor;

import cc.thonly.reverie_dreams.interfaces.ItemSettingsAccessorImpl;
import net.fabricmc.fabric.api.item.v1.FabricItem;
import net.minecraft.class_10162;
import net.minecraft.class_1792;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7699;
import net.minecraft.class_9323;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.gen.Accessor;

@Mixin(class_1792.class_1793.class)
public interface ItemSettingsAccessor extends FabricItem.Settings, ItemSettingsAccessorImpl {
    @Accessor("BLOCK_PREFIXED_TRANSLATION_KEY")
    public static class_10162<class_1792, String> BLOCK_PREFIXED_TRANSLATION_KEY() {
        throw new UnsupportedOperationException();
    }

    @Accessor("ITEM_PREFIXED_TRANSLATION_KEY")
    public static class_10162<class_1792, String> ITEM_PREFIXED_TRANSLATION_KEY() {
        throw new UnsupportedOperationException();
    }

    @Accessor("components")
    public class_9323.class_9324 getComponents();

    @Accessor("recipeRemainder")
    @Nullable
    public class_1792 getRecipeRemainder();

    @Accessor("requiredFeatures")
    public class_7699 getRequiredFeatures();

    @Accessor("registryKey")
    @Nullable
    public class_5321<class_1792> getRegistryKey();

    @Accessor("translationKey")
    public class_10162<class_1792, String> getTranslationKey();

    @Accessor("modelId")
    public class_10162<class_1792, class_2960> getModelId();
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/mixin/accessor/ItemSettingsAccessor.java <==
package cc.thonly.reverie_dreams.mixin.accessor;

import cc.thonly.reverie_dreams.interfaces.ItemSettingsAccessorImpl;
import net.fabricmc.fabric.api.item.v1.FabricItem;
import net.minecraft.class_10162;
import net.minecraft.class_1792;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7699;
import net.minecraft.class_9323;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.gen.Accessor;

@Mixin(class_1792.class_1793.class)
public interface ItemSettingsAccessor extends FabricItem.Settings, ItemSettingsAccessorImpl {
    @Accessor("BLOCK_DESCRIPTION_ID")
    public static class_10162<class_1792, String> BLOCK_PREFIXED_TRANSLATION_KEY() {
        throw new UnsupportedOperationException();
    }

    @Accessor("ITEM_DESCRIPTION_ID")
    public static class_10162<class_1792, String> ITEM_PREFIXED_TRANSLATION_KEY() {
        throw new UnsupportedOperationException();
    }

    @Accessor("components")
    public class_9323.class_9324 getComponents();

    @Accessor("craftingRemainingItem")
    @Nullable
    public class_1792 getRecipeRemainder();

    @Accessor("requiredFeatures")
    public class_7699 getRequiredFeatures();

    @Accessor("id")
    @Nullable
    public class_5321<class_1792> getRegistryKey();

    @Accessor("descriptionId")
    public class_10162<class_1792, String> getTranslationKey();

    @Accessor("model")
    public class_10162<class_1792, class_2960> getModelId();
}
